@@ -1,7 +1,7 @@
 package Config::IOD::Document;
 
-our $DATE = '2016-02-24'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2016-02-27'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010;
 use strict;
@@ -259,6 +259,52 @@ sub get_value {
     $self->{_dump_cache}{$section}{$key};
 }
 
+sub get_directive_before_key {
+    my ($self, $section, $key) = @_;
+
+    my $found;
+    $self->each_key(
+        sub {
+            my ($self, %args) = @_;
+            return if $found;
+            return unless $args{linum} > 1;
+            return unless $args{section} eq $section;
+            return unless $args{key} eq $key;
+            my $l = $self->{_parsed}[ $args{linum}-1-1 ];
+            return unless $l->[COL_TYPE] eq 'D';
+            my $p = $self->{_parser};
+            $found = [
+                $l->[COL_D_DIRECTIVE],
+                @{ $p->_parse_command_line($l->[COL_D_ARGS_RAW]) // [] },
+            ];
+        },
+    );
+    $found;
+}
+
+sub list_keys {
+    my $self = shift;
+    my $opts;
+    if (ref($_[0]) eq 'HASH') {
+        $opts = shift;
+    } else {
+        $opts = {};
+    }
+    my ($section) = @_;
+
+    my @res;
+    my %mem;
+    $self->each_key(
+        sub {
+            my ($self, %args) = @_;
+            return unless $args{section} eq $section;
+            return if $opts->{unique} && $mem{$args{key}}++;
+            push @res, $args{key};
+        },
+    );
+    @res;
+}
+
 sub _find_section {
     my $self = shift;
     my $opts;
@@ -740,7 +786,7 @@ Config::IOD::Document - Represent IOD document
 
 =head1 VERSION
 
-This document describes version 0.24 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2016-02-24.
+This document describes version 0.25 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2016-02-27.
 
 =head1 SYNOPSIS
 
@@ -952,6 +998,17 @@ C<get_value()> will avoid re-parsing the whole document. (The cache will
 automatically be discarded is one of document-modifying methods like
 C<delete_section()> is called.)
 
+=head2 $doc->get_directive_before_key($section, $key) => array
+
+Find directive right before a key. Directive must directly precede key line
+without any blank line, e.g.:
+
+ ;!lint_prereqs assume-used "undetected, used via Riap"
+ App::MyApp=0
+
+If found, will return an arrayref containing directive name and arguments.
+Otherwise, will return undef.
+
 =head2 $doc->insert_key([\%opts, ]$section, $key, $value)
 
 Insert a key named C<$name> with value C<$value> under C<$section>. Die on
@@ -1034,13 +1091,27 @@ If set to 1, will only list the first occurrence of each section.
 
 =back
 
+=head2 $doc->list_keys([ \%opts ], $section) => LIST
+
+List keys in the section named <$section>.
+
+Options:
+
+=over
+
+=item * unique => bool
+
+If set to 1, will only list the first occurrence of each key.
+
+=back
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Config-IOD>.
+Source repository is at L<https://github.com/sharyanto/perl-Config-IOD>.
 
 =head1 BUGS
 
